@@ -13,7 +13,7 @@ test_that("weather alerts works", {
 
   # Test with API response mock
   with_mock(
-    "hereR:::.get_content" = function(url) {
+    "hereR:::.async_request" = function(url, rps) {
       hereR:::mock$weather_alerts_response
     },
     weather_alerts <- weather(poi = poi, product = "alerts"),
